@@ -39,7 +39,6 @@ import pty
 
 from DistUpgradeApport import *
 
-from DistUpgradeController import DistUpgradeController
 from DistUpgradeView import DistUpgradeView, FuzzyTimeToStr, InstallProgress, FetchProgress
 
 import select
@@ -300,7 +299,6 @@ class KDEInstallProgressAdapter(InstallProgress):
         #FIXME, below to be tested
         #self.confDialogue.resize(self.confDialogue.minimumSizeHint())
         self.confDialogue.connect(self.confDialogue.show_difference_button, SIGNAL("clicked()"), self.showConffile)
-        self.confDialogue.show_difference_button.setEnabled(False)
 
         # workaround silly dpkg 
         if not os.path.exists(current):
@@ -439,6 +437,7 @@ class UpgraderMainWindow(QWidget):
 class DistUpgradeViewKDE(DistUpgradeView):
     """KDE frontend of the distUpgrade tool"""
     def __init__(self, datadir=None, logdir=None):
+        DistUpgradeView.__init__(self)
         # silence the PyQt4 logger
         logger = logging.getLogger("PyQt4")
         logger.setLevel(logging.INFO)
@@ -491,7 +490,7 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.app.connect(self.window_main.showTerminalButton, SIGNAL("clicked()"), self.showTerminal)
 
         #kdesu requires us to copy the xauthority file before it removes it when Adept is killed
-        fd, copyXauth = tempfile.mkstemp("", "adept")
+        copyXauth = tempfile.mktemp("", "adept")
         if 'XAUTHORITY' in os.environ and os.environ['XAUTHORITY'] != copyXauth:
             shutil.copy(os.environ['XAUTHORITY'], copyXauth)
             os.environ["XAUTHORITY"] = copyXauth
@@ -761,15 +760,15 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.changesDialogue.treeview_details.setHeaderLabels(["Packages"])
         self.changesDialogue.treeview_details.header().hide()
         for demoted in self.demotions:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("No longer supported %s") % demoted]) )
+            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("No longer supported %s") % demoted.name]) )
         for rm in self.toRemove:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Remove %s") % rm]) )
+            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Remove %s") % rm.name]) )
         for rm in self.toRemoveAuto:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Remove (was auto installed) %s") % rm]) )
+            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Remove (was auto installed) %s") % rm.name]) )
         for inst in self.toInstall:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Install %s") % inst]) )
+            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Install %s") % inst.name]) )
         for up in self.toUpgrade:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Upgrade %s") % up]) )
+            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Upgrade %s") % up.name]) )
 
         #FIXME resize label, stop it being shrinkable
         res = self.changesDialogue.exec_()
@@ -849,10 +848,10 @@ if __name__ == "__main__":
 
   cache = apt.Cache()
   for pkg in sys.argv[1:]:
-    if cache[pkg].isInstalled and not cache[pkg].isUpgradable: 
-      cache[pkg].markDelete(purge=True)
+    if cache[pkg].is_installed and not cache[pkg].isUpgradable: 
+      cache[pkg].mark_delete(purge=True)
     else:
-      cache[pkg].markInstall()
+      cache[pkg].mark_install()
   cache.commit(view._fetchProgress,view._installProgress)
 
   # keep the window open
