@@ -23,11 +23,10 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-import apt
-import gconf
-import gobject
-import glib
-import gtk
+from gi.repository import GLib
+from gi.repository import Gio
+from gi.repository import GObject
+from gi.repository import Gtk
 import locale
 import logging
 import sys
@@ -35,16 +34,18 @@ import time
 
 import UpdateManager.GtkProgress
 
-from gettext import gettext as _
+import gettext
 from optparse import OptionParser
 
 from DistUpgrade.utils import init_proxy
 
 from UpdateManager.DistUpgradeFetcher import DistUpgradeFetcherGtk
 from UpdateManager.MetaReleaseGObject import MetaRelease
-from UpdateManager.SimpleGtkbuilderApp import SimpleGtkbuilderApp
+from UpdateManager.SimpleGtk3builderApp import SimpleGtkbuilderApp
 
-gobject.threads_init()
+from gettext import gettext as _
+
+GObject.threads_init()
 
 # overwrite default upgrade fetcher and make it not show the
 # release notes by default
@@ -61,7 +62,7 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
   FETCH_TIMEOUT = 20
 
   def __init__(self, options):
-    SimpleGtkbuilderApp.__init__(self, options.datadir+"/glade/UpgradePromptDialog.ui", "update-manager")
+    SimpleGtkbuilderApp.__init__(self, options.datadir+"/gtkbuilder/UpgradePromptDialog.ui", "update-manager")
     self.new_dist = None
     logging.debug("runnign with devel=%s proposed=%s" % (
             options.devel_release, options.proposed_release))
@@ -73,19 +74,19 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
         self.build_ui()
         self.show_uri(options.test_uri)
     else:
-        glib.timeout_add_seconds(self.FETCH_TIMEOUT, self.timeout)
+        GObject.timeout_add_seconds(self.FETCH_TIMEOUT, self.timeout, None)
 
   def new_dist_available(self, meta_release, new_dist):
     logging.debug("new_dist_available: %s" % new_dist)
     self.new_dist = new_dist
-    client = gconf.client_get_default()
-    ignore_dist = client.get_string("/apps/update-manager/check_new_release_ignore")
+    client =  Gio.Settings("com.ubuntu.update-manager")
+    ignore_dist = client.get_string("check-new-release-ignore")
     # only honor the ignore list if the distro is still supported, otherwise
     # go into nag mode
     if (ignore_dist == new_dist.name and
         meta_release.no_longer_supported is None):
         logging.warn("found new dist '%s' but it is on the ignore list" % new_dist.name)
-        gtk.main_quit()
+        Gtk.main_quit()
     self.build_ui()
     self.window_main.set_title(_("Ubuntu %(version)s Upgrade Available") % {'version': new_dist.version})
     self.linkbutton_release_notes.set_uri(new_dist.releaseNotesURI)
@@ -101,12 +102,12 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
         show_dist_no_longer_supported_dialog(self.window_main)
   
   def build_ui(self):
-    import webkit
-    self.webkit_view = webkit.WebView()
+    from gi.repository import WebKit
+    self.webkit_view = WebKit.WebView()
     self.webkit_view.show()
     settings = self.webkit_view.get_settings()
     settings.set_property("enable-plugins", False)
-    # FIXME: do we want to have it in a gtk.ScrolledWindow ?
+    # FIXME: do we want to have it in a Gtk.ScrolledWindow ?
     #self.alignment_webkit_view.add(self.webkit_view)
     self.scrolledwindow_webkit_view.add(self.webkit_view)
 
@@ -122,26 +123,25 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
     logging.debug("ask me later")
     # check again in a week
     next_check = time.time() + 7*24*60*60
-    client = gconf.client_get_default()
-    client.set_int("/apps/update-notifier/release_check_time", int(next_check))
-    gtk.main_quit()
+    client = Gio.Settings("com.ubuntu.update-manager")
+    client.set_int("release-check-time", next_check)
+    Gtk.main_quit()
 
   def on_button_dont_upgrade_clicked(self, button):
     #print "don't upgrade"
     s = _("You have declined the upgrade to Ubuntu %s") % self.new_dist.version
     self.dialog_really_do_not_upgrade.set_markup("<b>%s</b>" % s)
-    if self.dialog_really_do_not_upgrade.run() == gtk.RESPONSE_OK:
-        client = gconf.client_get_default()
-        client.set_string("/apps/update-manager/check_new_release_ignore",
-                          self.new_dist.name)
-    gtk.main_quit()
+    if self.dialog_really_do_not_upgrade.run() == Gtk.ResponseType.OK:
+        client = Gio.Settings("com.ubuntu.update-manager")
+        client.set_string("check-new-release-ignore", self.new_dist.name)
+    Gtk.main_quit()
 
   def on_linkbutton_release_notes_clicked(self, linkbutton):
     # gtk will do the right thing if uri is set
     pass
 
   def window_delete_event_cb(self, window, event):
-    gtk.main_quit()
+    Gtk.main_quit()
 
   def show_uri(self, uri):
     logging.debug("using uri '%s'" % uri)
@@ -150,15 +150,23 @@ class CheckNewReleaseGtk(SimpleGtkbuilderApp):
 
   def _on_load_finished(self, view, frame):
     self.window_main.show_all()
-    # hide redundant release notes button
-    self.linkbutton_release_notes.hide()
 
-  def timeout(self):
+  def timeout(self, user_data):
     if self.new_dist is None:
       logging.warn("timeout reached, exiting")
-      gtk.main_quit()
+      Gtk.main_quit()
 
 if __name__ == "__main__":
+  APP="update-manager"
+  DIR="/usr/share/locale"
+
+  Gtk.init_check(sys.argv)
+
+  gettext.install(APP, DIR, unicode=True)
+  try:
+    locale.setlocale(locale.LC_ALL, "")
+  except:
+    pass
 
   init_proxy()
 
@@ -184,5 +192,5 @@ if __name__ == "__main__":
   # create object
   cnr = CheckNewReleaseGtk(options)
  
-  gtk.main()
+  Gtk.main()
 
