@@ -3,13 +3,17 @@
 set -e
 
 # update demotions
-(cd utils && ./demotions.py maverick natty > demoted.cfg)
+(cd utils && ./demotions.py natty oneiric > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 #(cd utils && ./demotions.py hardy lucid > demoted.cfg.hardy)
 
 # update base-installer
 (cd utils && ./update-base-installer.sh)
 
+# update apt_btrfs_snapshot.py copy, this nees a installed
+# apt-btrfs-snapshot on the build machine
+cp /usr/share/pyshared/apt_btrfs_snapshot.py DistUpgrade
+
 # (auto) generate the required html
 if [ ! -x /usr/bin/parsewiki ]; then
     echo "please sudo apt-get install parsewiki"
